@@ -6,8 +6,10 @@ import os
 import unittest
 from curses import error
 
+from logria.communication.input_handler import (CommandInputStream,
+                                                FileInputStream)
 from logria.communication.shell_output import Logria
-from logria.communication.input_handler import CommandInputStream, FileInputStream
+
 
 class TestCanLaunchApp(unittest.TestCase):
     """
@@ -23,7 +25,6 @@ class TestCanLaunchApp(unittest.TestCase):
             os.environ['TERM'] = 'dumb'
             app = Logria(None, False)
             app.start()
-            app.stop()
 
     def test_launch_with_command_stream(self):
         """
@@ -35,7 +36,6 @@ class TestCanLaunchApp(unittest.TestCase):
             stream = CommandInputStream(['ls', '-l'])
             app = Logria(stream, False)
             app.start()
-            app.stop()
 
     def test_launch_with_file_stream(self):
         """
@@ -47,4 +47,3 @@ class TestCanLaunchApp(unittest.TestCase):
             stream = FileInputStream(['readme.md'])
             app = Logria(stream, False)
             app.start()
-            app.stop()
